package com.nexgo.oaf.apiv3;

import android.content.Context;

import com.nexgo.oaf.apiv3.card.cpu.CPUCardHandler;
import com.nexgo.oaf.apiv3.card.memory.MemoryCardHandler;
import com.nexgo.oaf.apiv3.card.mifare.M1CardHandler;
import com.nexgo.oaf.apiv3.device.beeper.Beeper;
import com.nexgo.oaf.apiv3.device.led.LEDDriver;
import com.nexgo.oaf.apiv3.device.pinpad.PinPad;
import com.nexgo.oaf.apiv3.device.printer.Printer;
import com.nexgo.oaf.apiv3.device.reader.CardReader;
import com.nexgo.oaf.apiv3.device.reader.CardSlotTypeEnum;
import com.nexgo.oaf.apiv3.device.scanner.Scanner;
import com.nexgo.oaf.apiv3.device.serialport.SerialPortDriver;
import com.nexgo.oaf.apiv3.emv.EmvHandler;
import com.nexgo.oaf.apiv3.hsm.HSMDevice;

/**
 * Created by xiaox on 16/4/25.
 */

/**
 * 设备操作引擎
 */
public interface DeviceEngine {
    /**
     * 获取蜂鸣器操作对象
     *
     * @return {@link Beeper}
     */
    Beeper getBeeper();

    /**
     * 获取 LED 操作对像
     *
     * @return {@link LEDDriver}
     */
    LEDDriver getLEDDriver();

    /**
     * 获取打印机操作对象
     *
     * @return {@link Printer}
     */
    Printer getPrinter();

    /**
     * 获取串口操作对象
     *
     * @param portNo 串口号
     * @return {@link SerialPortDriver}
     */
    SerialPortDriver getSerialPortDriver(int portNo);

    /**
     * 获取读卡器操作对象
     *
     * @return {@link CardReader}
     */
    CardReader getCardReader();

    /**
     * 获取 CPU 卡操作对象
     *
     * @param slotType {@link CardSlotTypeEnum}
     * @return {@link CPUCardHandler}
     */
    CPUCardHandler getCPUCardHandler(CardSlotTypeEnum slotType);

    /**
     * 获取 M1卡操作对象
     *
     * @return {@link M1CardHandler}
     */
    M1CardHandler getM1CardHandler();

    /**
     * 获取Memory卡操作对像
     * @param slotType {@link CardSlotTypeEnum}
     * @return
     */
    MemoryCardHandler getMemoryCardHandler(CardSlotTypeEnum slotType);

    /**
     * 获取键盘操作对象
     *
     * @return {@link PinPad}
     */
    PinPad getPinPad();

    /**
     * 获取 emv 操作对象
     *
     * @param appId 应用 id,主要用于区分 aid 与 capk 存储路径
     * @return {@link EmvHandler}
     */
    EmvHandler getEmvHandler(String appId);

    /**
     * 获取扫码对象
     * @return {@link Scanner}
     */
    Scanner getScanner(Context context);

    /**
     * 获取安全模块操作对象
     * @return {@link HSMDevice}
     */
    HSMDevice getHSMDevice();
    /**
     * 设置系统时间
     *
     * @param context  上下文
     * @param datetime 时间,格式YYYYMMDDHHMMSS
     */
    void setSystemClock(Context context, String datetime);

    /**
     * 静默安装指定的App
     *
     * @param context     上下文
     * @param appFilePath apk 路径
     * @return {@link SdkResult}
     */
    int installApp(Context context, String appFilePath, OnAppOperatListener listener);

    /**
     * 静默卸载指定的App
     *
     * @param context     上下文
     * @param packageName 包名
     * @return {@link SdkResult}
     */
    int uninstallApp(Context context, String packageName, OnAppOperatListener listener);

    /**
     * 获取设备信息
     * @return {@link DeviceInfo}
     */
    DeviceInfo getDeviceInfo();


}
