package com.nexgo.oaf.apiv3.device.pinpad;

/**
 * Created by xiaox on 16/4/20.
 */

import com.nexgo.oaf.apiv3.SdkResult;

/**
 * 密码键盘操作类
 */
public interface PinPad {
    /**
     * 初始化密钥键盘,目前只支持内置
     *
     * @param ppType {@link PinPadTypeEnum}
     * @return {@link SdkResult} SdkResult.Success,SdkResult.Fail
     */
    int initPinPad(PinPadTypeEnum ppType);

    /**
     * 灌明文主密钥
     *
     * @param mKeyIdx    主密钥索引0~99
     * @param keyData    明文主密钥数据
     * @param keyDataLen 明文主密钥长度
     * @return {@link SdkResult} SdkResult.Success,SdkResult.Fail,SdkResult.Param_In_Invalid,SdkResult.PinPad_KeyIdx_Error
     */
    int writeMKey(int mKeyIdx, byte[] keyData, int keyDataLen);

    /**
     * 灌密文主密钥
     *
     * @param mKeyIdx    主密钥索引0~99
     * @param keyData    密文主密钥数据
     * @param keyDataLen 密文主密钥长度
     * @param decMKeyIdx 解密主密钥索引
     * @return {@link SdkResult} SdkResult.Success,SdkResult.Fail,SdkResult.Param_In_Invalid,SdkResult.PinPad_KeyIdx_Error
     */
    int writeMKey(int mKeyIdx, byte[] keyData, int keyDataLen, int decMKeyIdx);

    /**
     * 通过工厂出厂内置密钥tek灌密文主密钥
     *
     * @param mKeyIdx    主密钥索引0~99
     * @param keyData    密文主密钥数据
     * @param keyDataLen 密文主密钥长度
     * @param tekIdx     tek索引
     * @return {@link SdkResult} SdkResult.Success,SdkResult.Fail,SdkResult.Param_In_Invalid,SdkResult.PinPad_KeyIdx_Error
     */
    int writeMkeyByTek(int mKeyIdx, byte[] keyData, int keyDataLen, int tekIdx);

    /**
     * 母pos灌密钥
     *
     * @param portNo  打开串口号,波特率38400
     * @param timeout 超时时间，单件秒
     * @return {@link SdkResult} SdkResult.Success,SdkResult.Fail,SdkResult.TimeOut,SdkResult.PinPad_Input_Cancel
     */
    int loadKeyByCom(int portNo, int timeout);

    /**
     * 取消母pos灌密钥
     */
    void cancelLoadKey();

    /**
     * 灌工作密钥
     *
     * @param mKeyIdx    主密钥索引
     * @param wKeyType   {@link WorkKeyTypeEnum}
     * @param keyData    工作密钥密文数据
     * @param keyDataLen 密文长度
     * @return {@link SdkResult}
     */
    int writeWKey(int mKeyIdx, WorkKeyTypeEnum wKeyType, byte[] keyData, int keyDataLen);

    /**
     * 灌明文密钥（不支持国密SM4）
     * 可用于加解密
     *
     * @param keyIdx     明文密钥索引0~99
     * @param keyData    明文密钥数据
     * @param keyDateLen 明文密钥长度
     * @return {@link SdkResult}
     */
    int writePlainKey(int keyIdx, byte[] keyData, int keyDateLen);

    /**
     * 计算checkvalue
     *
     * @param mKeyIdx  主密钥索引
     * @param wKeyType {@link WorkKeyTypeEnum}
     * @return checkvalue, 失败返回 null
     */
    byte[] calcWKeyKCV(int mKeyIdx, WorkKeyTypeEnum wKeyType);

    /**
     * 工作密钥加解密
     *
     * @param mKeyIdx  主密钥索引
     * @param wKeyType {@link WorkKeyTypeEnum}
     * @param data     数据
     * @param dataLen  长度
     * @param calcMode {@link CalcModeEnum}
     * @return 结果, 失败返回 null
     */
    byte[] calcByWKey(int mKeyIdx, WorkKeyTypeEnum wKeyType, byte[] data, int dataLen, CalcModeEnum calcMode);

    /**
     * 通过工厂出厂内置密钥auk进行加解密运行
     *
     * @param aukIdx   auk索引
     * @param data     数据
     * @param dataLen  长度
     * @param keyMode  {@link DesKeyModeEnum}
     * @param calcMode {@link CalcModeEnum}
     * @return 结果, 失败返回 null
     */
    byte[] calcByAuk(int aukIdx, byte[] data, int dataLen, DesKeyModeEnum keyMode, CalcModeEnum calcMode);

    /**
     * 工作密钥加解密(支持双倍长密钥做DES算法)
     *
     * @param mKeyIdx  主密钥索引
     * @param wKeyType {@link WorkKeyTypeEnum}
     * @param data     数据
     * @param dataLen  长度
     * @param keyMode  {@link DesKeyModeEnum}
     * @param calcMode {@link CalcModeEnum}
     * @return 结果, 失败返回 null
     */
    byte[] desByWKey(int mKeyIdx, WorkKeyTypeEnum wKeyType, byte[] data, int dataLen, DesKeyModeEnum keyMode, CalcModeEnum calcMode);

    /**
     * 计算mac
     *
     * @param mKeyIdx    主密钥索引
     * @param macAlgMode {@link MacAlgorithmModeEnum}
     * @param data       数据
     * @return 结果, 失败返回 null
     */
    byte[] calcMac(int mKeyIdx, MacAlgorithmModeEnum macAlgMode, byte[] data);

    /**
     * 计算mac(支持双倍长密钥做DES算法)
     *
     * @param mKeyIdx    主密钥索引
     * @param macAlgMode {@link MacAlgorithmModeEnum}
     * @param keyMode    {@link DesKeyModeEnum}
     * @param data       数据
     * @return 结果，失败返回null
     */
    byte[] calcMac(int mKeyIdx, MacAlgorithmModeEnum macAlgMode, DesKeyModeEnum keyMode, byte[] data);

    /**
     * 计算mac(只支持dukpt)
     *
     * @param mKeyIdx    主密钥索引
     * @param macAlgMode {@link MacAlgorithmModeEnum}
     * @param keyMode    {@link DukptKeyModeEnum}
     * @param data       数据
     * @return 结果，失败返回null
     */
    byte[] calcMac(int mKeyIdx, MacAlgorithmModeEnum macAlgMode, DukptKeyModeEnum keyMode, byte[] data);

    /**
     * 明文密钥加解密（不支持国密SM4）
     *
     * @param keyIdx   明文密钥索引
     * @param data     数据
     * @param dataLen  长度
     * @param calcMode {@link CalcModeEnum}
     * @return 结果, 失败返回 null
     */
    byte[] desByPlainKey(int keyIdx, byte[] data, int dataLen, DesKeyModeEnum keyMode, CalcModeEnum calcMode);

    /**
     * 主密钥加密
     *
     * @param mKeyIdx 主密钥索引
     * @param data    数据
     * @param dataLen 长度
     * @return 结果, 失败返回 null
     */
    byte[] encryptByMKey(int mKeyIdx, byte[] data, int dataLen);

    /**
     * 清除主密钥
     *
     * @param mKeyIdx 主密钥索引
     * @return 成功或失败
     */
    boolean deleteMKey(int mKeyIdx);

    /**
     * 主密钥是否存在
     *
     * @param mKeyIdx 主密钥索引
     * @return 存在或不存在
     */
    boolean isKeyExist(int mKeyIdx);

    /**
     * 工作密钥是否存在
     *
     * @param mKeyIdx  主密钥索引
     * @param wKeyType {@link WorkKeyTypeEnum}
     * @return 存在或不存在
     */
    boolean isKeyExist(int mKeyIdx, WorkKeyTypeEnum wKeyType);

    /**
     * 格式化密钥区
     *
     * @return
     */
    boolean format();

    /**
     * 输入文本
     *
     * @param timeout  输入超时,单位秒
     * @param listener {@link OnPinPadInputListener}
     * @param mode     {@link InputModeEnum}
     * @return {@link SdkResult}
     */
    int inputText(int timeout, OnPinPadInputListener listener, InputModeEnum mode);

    /**
     * 设置密码键盘布局
     * 当调用此接口后，调用inputOnlinePin或inputOfflinePin时，密码键盘的布局由上层自己绘制，不使用系统默认的密码界面
     *
     * @param pinpadLayout 10个数字按键以及3个功能键的坐标位置
     * @return 10个数字按键对应的真实键值，顺序与入参中key0~10对应
     */
    byte[] setPinpadLayout(PinpadLayoutEntity pinpadLayout);

    /**
     * 输入联机密码
     *
     * @param pinLen     支持的长度,如{0x04,0x05,...0x0b}
     * @param timeout    输入超时,单位秒
     * @param panBlock   卡号,asc 编码
     * @param mKeyIdx    主密钥索引
     * @param pinAlgMode {@link PinAlgorithmModeEnum}
     * @param listener   {@link OnPinPadInputListener}
     * @return {@link SdkResult}
     */
    int inputOnlinePin(int[] pinLen, int timeout, byte[] panBlock, int mKeyIdx, PinAlgorithmModeEnum pinAlgMode, OnPinPadInputListener listener);

    /**
     * 输入脱机密码
     *
     * @param pinLen   支持的长度,如{0x04,0x05,...0x0b}
     * @param timeout  输入超时,单位秒
     * @param listener {@link OnPinPadInputListener}
     * @return {@link SdkResult}
     */
    int inputOfflinePin(int[] pinLen, int timeout, OnPinPadInputListener listener);

    /**
     * 是否键盘正在输入
     *
     * @return 成功或失败
     */
    boolean isInputting();

    /**
     * 取消键盘输入
     *
     * @return 成功或失败
     */
    boolean cancelInput();

    /**
     * 加密磁道数据
     *
     * @param mKeyIdx      主密钥
     * @param trackData    明文磁道数据
     * @param trackDataLen 明文磁道数据长度
     * @return 加密后的数据，失败返回null
     */
    byte[] encryptTrackData(int mKeyIdx, byte[] trackData, int trackDataLen);

    /**
     * 设置当前pinpad密钥的算法，对于所有的涉及到加解密的接口都起效。不调用此函数时，默认为des算法
     *
     * @param algMode {@link AlgorithmModeEnum} 算法类型
     */
    void setAlgorithmMode(AlgorithmModeEnum algMode);

    /**
     * 设置密码键盘模式
     *
     * @param keyboardMode {@link PinKeyboardModeEnum} 密码键盘类型
     */
    void setPinKeyboardMode(PinKeyboardModeEnum keyboardMode);

    /**
     * 设置密码键盘清除按键模式
     *
     * @param clearMode {@link PinKeyboardClearModeEnum} 清除按键类型
     */
    void setPinKeyboardClearMode(PinKeyboardClearModeEnum clearMode);

    /**
     * dukpt注入密钥
     *
     * @param mKeyIdx    密钥索引(0~19)
     * @param keyType    {@link DukptKeyTypeEnum}
     * @param keyData    密钥
     * @param keyDataLen 密钥长度
     * @param ksn        ksn
     * @return {@link SdkResult} SdkResult.Success,SdkResult.Fail,SdkResult.PinPad_KeyIdx_Error,SdkResult.Param_In_Invalid
     */
    int dukptKeyInject(int mKeyIdx, DukptKeyTypeEnum keyType, byte[] keyData, int keyDataLen, byte[] ksn);

    /**
     * ksn增加
     *
     * @param mKeyIdx 密钥索引(0~19)
     */
    void dukptKsnIncrease(int mKeyIdx);

    /**
     * 获取当前ksn
     *
     * @param mKeyIdx 密钥索引(0~19)
     * @return
     */
    byte[] dukptCurrentKsn(int mKeyIdx);

    /**
     * dukpt加密
     *
     * @param mKeyIdx 密钥索引(0~19)
     * @param keyMode {@link DukptKeyModeEnum}
     * @param data    数据
     * @param dataLen 数据长度
     * @return 结果, 失败返回 null
     */
    byte[] dukptEncrypt(int mKeyIdx, DukptKeyModeEnum keyMode, byte[] data, int dataLen);

    /**
     * dukpt加密
     *
     * @param mKeyIdx 密钥索引(0~19)
     * @param keyMode {@link DukptKeyModeEnum}
     * @param data    数据
     * @param dataLen 数据长度
     * @param desMode {@link DesAlgorithmModeEnum}
     * @param iv      初始向量，当desMode为CBC时生效
     * @return 结果, 失败返回 null
     */
    byte[] dukptEncrypt(int mKeyIdx, DukptKeyModeEnum keyMode, byte[] data, int dataLen, DesAlgorithmModeEnum desMode, byte[] iv);
}
