package com.nexgo.oaf.apiv3.device.printer;

import android.graphics.Bitmap;
import android.graphics.Typeface;
import android.os.Bundle;

import com.nexgo.oaf.apiv3.SdkResult;

/**
 * Created by xiaox on 16/4/20.
 */

/**
 * 打印机操作类
 */
public interface Printer {
    /**
     * 初始化打印机
     *
     * @return {@link SdkResult}
     */
    int initPrinter();

    /**
     * 设置行间距
     *
     * @param value 单位象素
     */
    void setLetterSpacing(int value);

    /**
     * 设置灰度
     *
     * @param level {@link GrayLevelEnum}
     */
    void setGray(GrayLevelEnum level);

    /**
     * 设置矢量字体，只用于追加矢量字体接口，对于点阵字体不起作用
     *
     * @param typeface 矢量字体
     */
    void setTypeface(Typeface typeface);

    /**
     * 开始打印
     *
     * @param rollPaperEnd 结束时是否要自动走纸
     * @param listener     {@link OnPrintListener}
     * @return {@link SdkResult}
     */
    int startPrint(boolean rollPaperEnd, OnPrintListener listener);

    /**
     * 获取打印机状态
     *
     * @return {@link SdkResult}
     */
    int getStatus();

    /**
     * 追加文本
     *
     * @param text       数据
     * @param fontsize   矢量字体大小,单位像素
     * @param align      {@link AlignEnum}
     * @param isBoldFont 是否加粗
     * @return {@link SdkResult}
     */
    int appendPrnStr(String text, int fontsize, AlignEnum align, boolean isBoldFont);

    /**
     * 追加文本
     *
     * @param text       数据
     * @param fontsize   矢量字体大小,单位像素
     * @param align      {@link AlignEnum}
     * @param ops        {@link LineOptionEntity}
     * @return {@link SdkResult}
     */
    int appendPrnStr(String text, int fontsize, AlignEnum align, LineOptionEntity ops);

    /**
     * 追加文本
     *
     * @param text  数据
     * @param font  点阵字体{@link FontEntity}
     * @param align {@link AlignEnum}
     * @return {@link SdkResult}
     */
    int appendPrnStr(String text, FontEntity font, AlignEnum align);

    /**
     * 追加文本
     *
     * @param text  数据
     * @param font  点阵字体{@link FontEntity}
     * @param align {@link AlignEnum}
     * @param ops   {@link LineOptionEntity}
     * @return {@link SdkResult}
     */
    int appendPrnStr(String text, FontEntity font, AlignEnum align, LineOptionEntity ops);

    /**
     * 追加文本,左右对齐
     *
     * @param leftText   左靠数据
     * @param rightText  右靠数据
     * @param fontsize   字体大小,单位像素
     * @param isBoldFont 是否加粗
     * @return {@link SdkResult}
     */
    int appendPrnStr(String leftText, String rightText, int fontsize, boolean isBoldFont);

    /**
     * 追加文本,左右对齐
     *
     * @param leftText   左靠数据
     * @param rightText  右靠数据
     * @param fontsize   字体大小,单位像素
     * @param ops        {@link LineOptionEntity}
     * @return {@link SdkResult}
     */
    int appendPrnStr(String leftText, String rightText, int fontsize, LineOptionEntity ops);

    /**
     * 追加文本,左右对齐
     *
     * @param leftText  左靠数据
     * @param rightText 右靠数据
     * @param font      点阵字体{@link FontEntity}
     * @return {@link SdkResult}
     */
    int appendPrnStr(String leftText, String rightText, FontEntity font);

    /**
     * 追加文本,左右对齐
     *
     * @param leftText  左靠数据
     * @param rightText 右靠数据
     * @param font      点阵字体{@link FontEntity}
     * @param ops       {@link LineOptionEntity}
     * @return {@link SdkResult}
     */
    int appendPrnStr(String leftText, String rightText, FontEntity font, LineOptionEntity ops);

    /**
     * 追加 bitmap
     *
     * @param bitmap 数据
     * @param align  {@link AlignEnum}
     * @return {@link SdkResult}
     */
    int appendImage(Bitmap bitmap, AlignEnum align);

    /**
     * 追加一维码
     *
     * @param content       生成一维码的内容
     * @param height        生成一维码的高度，建议可为50
     * @param margin        生成一维码条码距离上下边框空白大小，默认可为0
     * @param scale         放大倍数，大于等于1，建议可为2
     * @param barcodeFormat {@link BarcodeFormatEnum}
     * @param align         {@link AlignEnum}
     * @return {@link SdkResult}
     */
    int appendBarcode(String content, int height, int margin, int scale, BarcodeFormatEnum barcodeFormat, AlignEnum align);

    /**
     * 追加二维码
     *
     * @param content 生成二维码的内容
     * @param height  期望生成打印图片高度
     * @param align   对齐方式
     * @return {@link SdkResult}
     */
    int appendQRcode(String content, int height, AlignEnum align);

    /**
     * 追加二维码
     *
     * @param content 生成二维码的内容
     * @param height  期望生成打印图片高度
     * @param version 二维码版本，值1~40，
     * @param level   纠错等级，从低到高0~3
     * @param align   对齐方式
     * @return {@link SdkResult}
     */
    int appendQRcode(String content, int height, int version, int level, AlignEnum align);

    /**
     * 走纸
     *
     * @param value 单位象素
     */
    void feedPaper(int value);

    /**
     * 剪纸
     */
    void cutPaper();
}
