package com.nexgo.oaf.apiv3.device.reader;

import com.nexgo.oaf.apiv3.SdkResult;

import java.util.HashSet;

/**
 * Created by xiaox on 16/4/26.
 */

/**
 * 读卡器操作
 */
public interface CardReader {
    /**
     * 寻卡
     *
     * @param slotTypes {@link CardSlotTypeEnum} 要同时寻找的卡槽
     * @param timeout   超时时间,单位秒
     * @param listener  {@link OnCardInfoListener}
     * @return {@link SdkResult}
     */
    int searchCard(HashSet<CardSlotTypeEnum> slotTypes, int timeout, OnCardInfoListener listener);

    /**
     * 停止寻卡
     */
    void stopSearch();

    /**
     * 打开卡槽
     * 如果已经调用searchCard寻到卡，则无需再调用open打开
     * @param cardSlotType 卡槽类型
     */
    void open(CardSlotTypeEnum cardSlotType);

    /**
     * 关闭卡槽
     *
     * @param cardSlotType 卡槽类型
     */
    void close(CardSlotTypeEnum cardSlotType);

    /**
     * 卡槽是否有卡
     *
     * @param cardSlotType {@link CardSlotTypeEnum} 要探测的卡槽
     * @return 成功或失败
     */
    boolean isCardExist(CardSlotTypeEnum cardSlotType);

    /**
     * 获取非接卡片类型
     * @param cardSlotType
     * @return
     */
    RfCardTypeEnum getRfCardType(CardSlotTypeEnum cardSlotType);

    /**
     * 复位初始 ETU
     *
     * @param cardSlotType 卡槽类型
     * @param val          0:372(标准卡，缺省支持自适应 4 倍频)
     *                     1:186(双倍频)
     *                     2:93(4 倍频)
     */
    void setETU(CardSlotTypeEnum cardSlotType, int val);
}
