package com.nexgo.oaf.apiv3.device.serialport;

/**
 * Created by xiaox on 16/4/20.
 */

import com.nexgo.oaf.apiv3.SdkResult;

/**
 * 串口操作
 */
public interface SerialPortDriver {
    /**
     * 串口连接
     *
     * @param entity {@link SerialCfgEntity}
     * @return {@link SdkResult} SdkResult.Param_In_Invalid,SdkResult.SerialPort_Invalid_Communication_Parameter,SdkResult.Success,SdkResult.SerialPort_Connect_Fail
     */
    int connect(SerialCfgEntity entity);

    /**
     * 发送数据
     *
     * @param data    数据
     * @param dataLen 长度
     * @return {@link SdkResult} SdkResult.Param_In_Invalid,SdkResult.SerialPort_Port_Not_Open,SdkResult.Success,SdkResult.SerialPort_Send_Fail
     */
    int send(byte[] data, int dataLen);

    /**
     * 接收数据
     *
     * @param buffer  数据
     * @param recvLen 缓存大小
     * @param timeout 超时,单位毫秒
     * @return {@link SdkResult} SdkResult.Param_In_Invalid,SdkResult.SerialPort_Port_Not_Open,SdkResult.SerialPort_Timeout_Receiving_Data,SdkResult.SerialPort_Other_Error,
     */
    int recv(byte[] buffer, int recvLen, long timeout);

    /**
     * 断开连接
     *
     * @return {@link SdkResult} SdkResult.SerialPort_Port_Not_Open,SdkResult.Success,SdkResult.SerialPort_DisConnect_Fail
     */
    int disconnect();

    /**
     * 清除缓冲区
     */
    void clrBuffer();
}
