package com.nexgo.oaf.apiv3.emv;

import com.nexgo.oaf.apiv3.SdkResult;

import java.util.List;

/**
 * Created by xiaox on 16/4/20.
 */

/**
 * emv流程操作
 */
public interface EmvHandler {
    /**
     * 开始 emv 流程
     *
     * @param transData {@link EmvTransDataEntity}
     * @param listener  {@link OnEmvProcessListener}
     * @return {@link SdkResult} SdkResult.Param_In_Invalid,SdkResult.Success
     */
    int emvProcess(EmvTransDataEntity transData, OnEmvProcessListener listener);

    /**
     * 取消emv流程
     */
    void emvProcessCancel();

    /**
     * 初始化 emv 内核
     *
     * @param cfgTlv tlv 数据
     * @return {@link SdkResult} SdkResult.Param_In_Invalid,SdkResult.Success,SdkResult.Fail
     */
    int initTermConfig(byte[] cfgTlv);

    /**
     * 设置 aid
     *
     * @param aidParaTlvList 数据
     * @param <T>            类型只能是byte[]或是AidEntity
     * @return {@link SdkResult} SdkResult.Param_In_Invalid,SdkResult.Success,SdkResult.Fail
     */
    <T> int setAidParaList(List<T> aidParaTlvList);

    /**
     * 设置DynamicReaderLimit，针对paypass,paywave
     *
     * @param drlEntityList {@link DynamicReaderLimitEntity} 设置DynamicReaderLimit列表
     * @return {@link SdkResult} SdkResult.Param_In_Invalid,SdkResult.Success,SdkResult.Fail
     */
    int setDynamicReaderLimitList(List<DynamicReaderLimitEntity> drlEntityList);

    /**
     * 设置 capk
     *
     * @param capkTlvList 数据
     * @param <T>         类型只能是byte[]或是AidEntity
     * @return {@link SdkResult} SdkResult.Param_In_Invalid,SdkResult.Success,SdkResult.Fail
     */
    <T> int setCAPKList(List<T> capkTlvList);

    /**
     * 获取 tag
     *
     * @param tag    tag
     * @param pathId {@link EmvDataSourceEnum}
     * @return 数据, 失败返回 null
     */
    byte[] getTlv(byte[] tag, EmvDataSourceEnum pathId);

    /**
     * 设置 tag
     *
     * @param tag   tag
     * @param value 数据
     * @return {@link SdkResult} SdkResult.Param_In_Invalid,SdkResult.Success,SdkResult.Fail
     */
    int setTlv(byte[] tag, byte[] value);

    /**
     * 读取日志
     *
     * @param channelType {@link EmvChannelTypeEnum}
     * @param listener    {@link OnEmvProcessListener}
     * @return {@link SdkResult} SdkResult.Param_In_Invalid,SdkResult.Success
     */
    int getEmvCardLog(EmvChannelTypeEnum channelType, OnEmvProcessListener listener);

    /**
     * 读取圈存日志
     *
     * @param channelType {@link EmvChannelTypeEnum}
     * @param listener    {@link OnEmvProcessListener}
     * @return {@link SdkResult} SdkResult.Param_In_Invalid,SdkResult.Success
     */
    int getEmvCardLoadLog(EmvChannelTypeEnum channelType, OnEmvProcessListener listener);

    /**
     * 清除日志
     *
     * @return SdkResult.Success, SdkResult.Fail
     */
    int clearLog();

    /**
     * 读取电子现金余额
     *
     * @param channelType {@link EmvChannelTypeEnum}
     * @param listener    {@link OnEmvProcessListener}
     * @return {@link SdkResult} SdkResult.Param_In_Invalid,SdkResult.Success
     */
    int emvGetEcBalance(EmvChannelTypeEnum channelType, OnEmvProcessListener listener);

    /**
     * 输入金额后调用,通知emv内核继续流程
     *
     * @param amount 金额,必须格式化为12位金额格式,如在中国1.01元，则格式为000000000101
     */
    void onSetRequestAmountResponse(String amount);

    /**
     * 应用列表选择后调用,通知emv内核继续流程
     *
     * @param selResult 索引,从1开始
     */
    void onSetSelAppResponse(int selResult);

    /**
     * 确认是否使用电子现金后调用,通知emv内核继续流程
     *
     * @param isConfirm 是否确认
     */
    void onSetConfirmEcSwitchResponse(boolean isConfirm);

    /**
     * 卡号确认后调用,通知emv内核继续流程
     *
     * @param isConfirm 是否确认
     */
    void onSetConfirmCardNoResponse(boolean isConfirm);

    /**
     * 证书确认后调用,通知emv内核继续流程
     *
     * @param isVerify 是否确认
     */
    void onSetCertVerifyResponse(boolean isVerify);

    /**
     * 联机返回后调用,通知emv内核走二次授权
     *
     * @param retCode {@link SdkResult} 联机成功或是联机失败 SdkResult.Success,SdkResult.Fail
     * @param result  {@link EmvOnlineResultEntity}
     */
    void onSetOnlineProcResponse(int retCode, EmvOnlineResultEntity result);


    /**
     * 输入完密码后调用,通知emv内核继续流程
     *
     * @param isConfirm 是否按了确认键
     * @param isBypass  是否没有输入密码,直接按确认键
     */
    void onSetPinInputResponse(boolean isConfirm, boolean isBypass);

    /**
     * 显示重新放卡并寻卡复位成功后，通知emv内核继续流程
     *
     * @param isSuccess 是否成功
     */
    void onSetReadCardAgainResponse(boolean isSuccess);

    /**
     * 删除所有的aid
     */
    void delAllAid();

    /**
     * 删除所有的capk
     */
    void delAllCapk();

    /**
     * 删除一条aid
     *
     * @param aid aid
     * @return 成功或失败
     */
    boolean delOneAid(byte[] aid);

    /**
     * 删除一条capk
     *
     * @param rid     rid
     * @param capkIdx capk索引
     * @return 成功或失败
     */
    boolean delOneCapk(byte[] rid, int capkIdx);

    /**
     * 通过TAG组TLV数据，如联机机55域tag
     * String[] TAGS = {"9f26", "9f27", "9f10", "9f37", "9f36", "95", "9a", "9c", "9f02", "5f2a", "82", "9f1a", "9f03","9f33", "9f34", "9f35", "9f1e", "9f09", "84", "9f41"}
     *
     * @return TLV数据
     */
    String getTlvByTags(String[] tags);

    /**
     * 获取QPBOC失败错误码，只针对中国银联qpboc
     *
     * @return {@link QpbocErrCodeEnum}
     */
    QpbocErrCodeEnum getQPBOCErrCode();

    /**
     * 打开或关闭emv内核的调试日志，默认关闭
     *
     * @param isEnable true打开，false关闭
     */
    void emvDebugLog(boolean isEnable);

    /**
     * 获取EMV流程模式，主要用于判断非接是走了EMV还是MSD
     *
     * @return
     */
    EmvModeEnum getEmvContactlessMode();

    /**
     * 获取aid列表总数
     *
     * @return 总数
     */
    int getAidListNum();

    /**
     * 获取capk列表总数
     *
     * @return 总数
     */
    int getCapkListNum();

    /**
     * 获取aid列表
     *
     * @return aid列表，无aid列表则返回null
     */
    List<AidEntity> getAidList();

    /**
     * 获取capk列表
     *
     * @return capk列表，无capk列表则返回null
     */
    List<CapkEntity> getCapkList();
}
