package com.nexgo.oaf.apiv3.emv;

/**
 * EMV交易数据类
 * EmvAlgorithmTypeEnum algType 算法标识
 * EmvTransFlowEnum procType 交易流程
 * String traceNo 交易流水号，8个字符
 * String transAmt 交易金额，12个字符
 * String cashbackAmt cashBack金额，12个字符
 * String transDate 交易日期，6个字符，格式yyMMdd
 * String transTime 交易时间，6个字条，格式hhmmss
 * String merName 商户名称
 * String merId 商户号
 * String termId 终端号
 * byte B9C 交易类型
 * 消费00,预授权03,余额查询31,退货20,消费撤销20,预授权撤销20,
 * 预授权完成通知00,预授权完成请求00,预授权完成请求撤销20,联机、脱机余额查询31,查IC卡明细/圈存明细31,现金圈存63,指定帐户圈存60,
 * 非指定帐户圈存62,现金充值撤销17,cash01,cashback
 * boolean isSupportEC 是否支持电子现金，设置为true之后，如果卡片支持电子现金，则会回调OnEmvProcessListener.onConfirmEcSwitch
 * EmvChannelTypeEnum channelType 用卡方式/
 * boolean isForceOnline 是否强制联机
 * boolean isDefaultEC 是否默认使用电子现金，设置为true之后，如果isSupportEC也为true,则不会回调OnEmvProcessListener.onConfirmEcSwitch
 */
public class EmvTransDataEntity {
    private EmvAlgorithmTypeEnum algType;
    private EmvTransFlowEnum procType;
    private String traceNo;
    private String transAmt;
    private String cashbackAmt;
    private String transDate;
    private String transTime;
    private String merName;
    private String merId;
    private String termId;
    private byte B9C;
    private boolean isSupportEC;
    private EmvChannelTypeEnum channelType;
    private boolean isForceOnline;
    private boolean isDefaultEC;

    public boolean isDefaultEC() {
        return isDefaultEC;
    }

    public void setIsDefaultEC(boolean defaultEC) {
        isDefaultEC = defaultEC;
    }

    public EmvAlgorithmTypeEnum getAlgType() {
        return algType;
    }

    public void setAlgType(EmvAlgorithmTypeEnum algType) {
        this.algType = algType;
    }

    public EmvTransFlowEnum getProcType() {
        return procType;
    }

    public void setProcType(EmvTransFlowEnum procType) {
        this.procType = procType;
    }

    public String getTraceNo() {
        return traceNo;
    }

    public void setTraceNo(String traceNo) {
        this.traceNo = traceNo;
    }

    public String getTransAmt() {
        return transAmt;
    }

    public void setTransAmt(String transAmt) {
        this.transAmt = transAmt;
    }

    public String getCashbackAmt() {
        return cashbackAmt;
    }

    public void setCashbackAmt(String cashbackAmt) {
        this.cashbackAmt = cashbackAmt;
    }

    public String getTransDate() {
        return transDate;
    }

    public void setTransDate(String transDate) {
        this.transDate = transDate;
    }

    public String getTransTime() {
        return transTime;
    }

    public void setTransTime(String transTime) {
        this.transTime = transTime;
    }

    public String getMerName() {
        return merName;
    }

    public void setMerName(String merName) {
        this.merName = merName;
    }

    public String getMerId() {
        return merId;
    }

    public void setMerId(String merId) {
        this.merId = merId;
    }

    public String getTermId() {
        return termId;
    }

    public void setTermId(String termId) {
        this.termId = termId;
    }

    public byte getB9C() {
        return B9C;
    }

    public void setB9C(byte b9C) {
        B9C = b9C;
    }

    public boolean isSupportEC() {
        return isSupportEC;
    }

    public void setIsSupportEC(boolean isSupportEC) {
        this.isSupportEC = isSupportEC;
    }

    public EmvChannelTypeEnum getChannelType() {
        return channelType;
    }

    public void setChannelType(EmvChannelTypeEnum channelType) {
        this.channelType = channelType;
    }

    public boolean isForceOnline() {
        return isForceOnline;
    }

    public void setIsForceOnline(boolean forceOnline) {
        isForceOnline = forceOnline;
    }
}
