package com.nexgo.oaf.apiv3.emv;

import com.nexgo.oaf.apiv3.SdkResult;
import com.nexgo.oaf.apiv3.device.reader.CardInfoEntity;

import java.util.List;

/**
 * Created by xiaox on 16/4/20.
 */

/**
 * emv流程监听
 */
public interface OnEmvProcessListener {

    /**
     * 回调请求输入金额（当交易未输入金额时触发）,后要调用EmvHandler.onSetRequestAmountResponse
     */
    void onRequestAmount();

    /**
     * 回调应用列表选择,后要调用EmvHandler.onSetSelAppResponse
     * @param appNameList 应用名显示列表
     * @param appInfoList 卡片候选应用信息
     * @param isFirstSelect 是否第一次选择
     */
    void onSelApp(List<String> appNameList, List<CandidateAppInfoEntity> appInfoList, boolean isFirstSelect);

    /**
     * 是否使用电子现金（当交易设置为支持电子现金，同时卡片也支持时触发）,后要调用EmvHandler.onSetConfirmEcSwitchResponse
     */
    void onConfirmEcSwitch();

    /**
     * 卡号确认,后要调用EmvHandler.onSetConfirmCardNoResponse
     *
     * @param cardInfo 卡号
     */
    void onConfirmCardNo(CardInfoEntity cardInfo);

    /**
     * 输入密码,后要调用EmvHandler.onSetPinInputResponse
     *
     * @param isOnlinePin 是否联机密码
     * @param leftTimes   脱机密码剩余输入次数
     */
    void onCardHolderInputPin(boolean isOnlinePin, int leftTimes);

    /**
     * 确认证件,后要调用EmvHandler.onSetCertVerifyResponse
     *
     * @param certName 证件名称
     * @param certInfo 证件信息
     */
    void onCertVerify(String certName, String certInfo);

    /**
     * 请求联机,后要调用EmvHandler.onSetOnlineProcResponse
     */
    void onOnlineProc();

    /**
     * paywave联机后有脚本需要更新时，如果卡片已移开，需要提示有脚本更新重新放卡，并完成寻卡复位
     */
    void onReadCardAgain();

    /**
     * 流程结果,非接转联机确认完卡号后,直接回调这里
     *
     * @param retCode {@link SdkResult}
     * @param entity  {@link EmvProcessResultEntity}
     */
    void onFinish(int retCode, EmvProcessResultEntity entity);
}
